@@ -279,7 +279,7 @@ def _singleframe_to_nifti(grouped_dicoms, output_file):
 
     logger.info('Creating affine')
     # Create the nifti header info
-    affine = common.create_affine(grouped_dicoms[0])
+    affine, slice_increment = common.create_affine(grouped_dicoms[0])
 
     logger.info('Creating nifti')
     # Convert to nifti
@@ -314,9 +314,12 @@ def _singleframe_to_nifti(grouped_dicoms, output_file):
                 'BVEC_FILE': bvec_file,
                 'NII': nii_image,
                 'BVAL': bval,
-                'BVEC': bvec}
+                'BVEC': bvec,
+                'MAX_SLICE_INCREMENT': slice_increment}
+
     return {'NII_FILE': output_file,
-            'NII': nii_image}
+            'NII': nii_image,
+            'MAX_SLICE_INCREMENT': slice_increment}
 
 
 def _singleframe_to_block(grouped_dicoms):
