@@ -198,7 +198,7 @@ def _classic_4d_to_nifti(grouped_dicoms, output_file):
 
     logger.info('Creating affine')
     # Create the nifti header info
-    affine = common.create_affine(grouped_dicoms[0])
+    affine, slice_increment = common.create_affine(grouped_dicoms[0])
 
     logger.info('Creating nifti')
     # Convert to nifti
@@ -228,10 +228,12 @@ def _classic_4d_to_nifti(grouped_dicoms, output_file):
                 'BVEC_FILE': bvec_file,
                 'NII': nii_image,
                 'BVAL': bval,
-                'BVEC': bvec}
+                'BVEC': bvec,
+                'MAX_SLICE_INCREMENT': slice_increment}
 
     return {'NII_FILE': output_file,
-            'NII': nii_image}
+            'NII': nii_image,
+            'MAX_SLICE_INCREMENT': slice_increment}
 
 
 def _classic_get_grouped_dicoms(dicom_input):
