@@ -22,7 +22,7 @@ def resample_single_nifti(input_nifti):
     output_image.to_filename(input_nifti)
 
 
-def resample_nifti_images(nifti_images):
+def resample_nifti_images(nifti_images, voxel_size=None):
     """
     In this function we will create an orthogonal image and resample the original images to this space
 
@@ -46,9 +46,10 @@ def resample_nifti_images(nifti_images):
     """
 
     # get the smallest voxelsize and use that
-    voxel_size = nifti_images[0].header.get_zooms()
-    for nifti_image in nifti_images[1:]:
-        voxel_size = numpy.minimum(voxel_size, nifti_image.header.get_zooms())
+    if voxel_size is None:
+        voxel_size = nifti_images[0].header.get_zooms()
+        for nifti_image in nifti_images[1:]:
+            voxel_size = numpy.minimum(voxel_size, nifti_image.header.get_zooms())
 
     x_axis_world = numpy.transpose(numpy.dot(nifti_images[0].affine, [[1], [0], [0], [0]]))[0, :3]
     y_axis_world = numpy.transpose(numpy.dot(nifti_images[0].affine, [[0], [1], [0], [0]]))[0, :3]
@@ -73,13 +74,8 @@ def resample_nifti_images(nifti_images):
                         [0, original_size[1], original_size[2]],
                         [original_size[0], original_size[1], original_size[2]]]
 
-        minaffine = nifti_images[0].affine
-        maxaffine = nifti_images[-1].affine
         for point in points_image[:4]:
-            points_world.append(numpy.transpose(numpy.dot(minaffine,
-                                                          [[point[0]], [point[1]], [point[2]], [1]]))[0, :3])
-        for point in points_image[4:]:
-            points_world.append(numpy.transpose(numpy.dot(maxaffine,
+            points_world.append(numpy.transpose(numpy.dot(nifti_image.affine,
                                                           [[point[0]], [point[1]], [point[2]], [1]]))[0, :3])
 
     projections = []
@@ -105,23 +101,20 @@ def resample_nifti_images(nifti_images):
     new_affine = _create_affine(x_axis_world, y_axis_world, z_axis_world, origin, voxel_size)
 
     # Resample each image
-    resampled_images = []
+    combined_image_data = numpy.full(new_shape, settings.resample_padding, dtype=nifti_images[0].get_data().dtype)
     for nifti_image in nifti_images:
         image_affine = nifti_image.affine
         combined_affine = numpy.linalg.inv(new_affine).dot(image_affine)
         matrix, offset = nibabel.affines.to_matvec(numpy.linalg.inv(combined_affine))
-        resampled_images.append(scipy.ndimage.affine_transform(nifti_image.get_data(),
-                                                               matrix=matrix,
-                                                               offset=offset,
-                                                               output_shape=new_shape,
-                                                               output=nifti_image.get_data().dtype,
-                                                               order=settings.resample_spline_interpolation_order,
-                                                               mode='constant',
-                                                               cval=settings.resample_padding,
-                                                               prefilter=False))
-
-    combined_image_data = numpy.full(new_shape, settings.resample_padding, dtype=resampled_images[0].dtype)
-    for resampled_image in resampled_images:
+        resampled_image = scipy.ndimage.affine_transform(nifti_image.get_data(),
+                                                         matrix=matrix,
+                                                         offset=offset,
+                                                         output_shape=new_shape,
+                                                         output=nifti_image.get_data().dtype,
+                                                         order=settings.resample_spline_interpolation_order,
+                                                         mode='constant',
+                                                         cval=settings.resample_padding,
+                                                         prefilter=False)
         combined_image_data[combined_image_data == settings.resample_padding] = \
             resampled_image[combined_image_data == settings.resample_padding]
 
